quantizationtools.ParallelJobHandlerWorker
==========================================

.. abjad-lineage:: abjad.tools.quantizationtools.ParallelJobHandlerWorker.ParallelJobHandlerWorker

.. autoclass:: abjad.tools.quantizationtools.ParallelJobHandlerWorker.ParallelJobHandlerWorker

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.quantizationtools.ParallelJobHandlerWorker.ParallelJobHandlerWorker.authkey
      ~abjad.tools.quantizationtools.ParallelJobHandlerWorker.ParallelJobHandlerWorker.daemon
      ~abjad.tools.quantizationtools.ParallelJobHandlerWorker.ParallelJobHandlerWorker.exitcode
      ~abjad.tools.quantizationtools.ParallelJobHandlerWorker.ParallelJobHandlerWorker.ident
      ~abjad.tools.quantizationtools.ParallelJobHandlerWorker.ParallelJobHandlerWorker.is_alive
      ~abjad.tools.quantizationtools.ParallelJobHandlerWorker.ParallelJobHandlerWorker.join
      ~abjad.tools.quantizationtools.ParallelJobHandlerWorker.ParallelJobHandlerWorker.name
      ~abjad.tools.quantizationtools.ParallelJobHandlerWorker.ParallelJobHandlerWorker.pid
      ~abjad.tools.quantizationtools.ParallelJobHandlerWorker.ParallelJobHandlerWorker.run
      ~abjad.tools.quantizationtools.ParallelJobHandlerWorker.ParallelJobHandlerWorker.start
      ~abjad.tools.quantizationtools.ParallelJobHandlerWorker.ParallelJobHandlerWorker.terminate
      ~abjad.tools.quantizationtools.ParallelJobHandlerWorker.ParallelJobHandlerWorker.__eq__
      ~abjad.tools.quantizationtools.ParallelJobHandlerWorker.ParallelJobHandlerWorker.__format__
      ~abjad.tools.quantizationtools.ParallelJobHandlerWorker.ParallelJobHandlerWorker.__hash__
      ~abjad.tools.quantizationtools.ParallelJobHandlerWorker.ParallelJobHandlerWorker.__ne__
      ~abjad.tools.quantizationtools.ParallelJobHandlerWorker.ParallelJobHandlerWorker.__repr__

Bases
-----

- :py:class:`multiprocessing.process.Process <multiprocessing.process.Process>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.ParallelJobHandlerWorker.ParallelJobHandlerWorker.exitcode
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.ParallelJobHandlerWorker.ParallelJobHandlerWorker.ident
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.ParallelJobHandlerWorker.ParallelJobHandlerWorker.pid
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.quantizationtools.ParallelJobHandlerWorker.ParallelJobHandlerWorker.authkey
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.ParallelJobHandlerWorker.ParallelJobHandlerWorker.daemon
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.ParallelJobHandlerWorker.ParallelJobHandlerWorker.name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.quantizationtools.ParallelJobHandlerWorker.ParallelJobHandlerWorker.is_alive
   :noindex:

.. automethod:: abjad.tools.quantizationtools.ParallelJobHandlerWorker.ParallelJobHandlerWorker.join
   :noindex:

.. automethod:: abjad.tools.quantizationtools.ParallelJobHandlerWorker.ParallelJobHandlerWorker.run
   :noindex:

.. automethod:: abjad.tools.quantizationtools.ParallelJobHandlerWorker.ParallelJobHandlerWorker.start
   :noindex:

.. automethod:: abjad.tools.quantizationtools.ParallelJobHandlerWorker.ParallelJobHandlerWorker.terminate
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.quantizationtools.ParallelJobHandlerWorker.ParallelJobHandlerWorker.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.ParallelJobHandlerWorker.ParallelJobHandlerWorker.__format__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.ParallelJobHandlerWorker.ParallelJobHandlerWorker.__hash__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.ParallelJobHandlerWorker.ParallelJobHandlerWorker.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.ParallelJobHandlerWorker.ParallelJobHandlerWorker.__repr__
   :noindex:
